==> haskell-js-jquery-3.3.1-1059-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.3.1
visibility:           public
id:                   js-jquery-3.3.1-4K9JkM0Bi5LAzuBRrcuAFa
key:                  js-jquery-3.3.1-4K9JkM0Bi5LAzuBRrcuAFa
license:              MIT
copyright:            Neil Mitchell 2014-2018
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  8a929fa594be191d5a0a88a3bde21472
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.3.1-4K9JkM0Bi5LAzuBRrcuAFa
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.3.1-1060-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.3.1
visibility:           public
id:                   js-jquery-3.3.1-6uLgCbeynTzFavx7nfaaFK
key:                  js-jquery-3.3.1-6uLgCbeynTzFavx7nfaaFK
license:              MIT
copyright:            Neil Mitchell 2014-2018
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  fa58f77527a2207480710f36739cbd88
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.3.1-6uLgCbeynTzFavx7nfaaFK
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
